@@ -42,6 +42,7 @@ import httplib
 import json
 import os
 import pkg_resources
+import platform
 import shutil
 import socket
 import subprocess
@@ -326,7 +327,7 @@ def get_gh_info(url):
     return url_paths[1], url_paths[2], url_paths[3], '/'.join(url_paths[4:])
 
 
-def fetch_github_api(url, data=None):
+def __fetch_github_api(url, data):
     try:
         if data is not None:
             req = urllib2.Request(url=url, data=data)
@@ -337,7 +338,24 @@ def fetch_github_api(url, data=None):
         error("Failed to fetch github API '{0}': {1}"
               .format(url, e))
         return None
-    return json.loads(raw_gh_api.read())
+    return json.load(raw_gh_api)
+
+
+def fetch_github_api(url, data=None, use_pagination=False, only_page=None):
+    if not use_pagination:
+        return __fetch_github_api(url, data)
+    items = []
+    page_count = only_page or 1
+    while True:
+        url_ = url + "?page=" + str(page_count)
+        page_count += 1
+        page_items = __fetch_github_api(url_, data)
+        if page_items is None:
+            return page_items
+        items.extend(page_items)
+        if not page_items or only_page:
+            break
+    return items
 
 
 def create_fork(org, repo, user, password):
@@ -416,7 +434,7 @@ def open_pull_request(track, repository, distro):
         return
     # Check for fork
     info(fmt("@{bf}@!==> @|@!Checking for rosdistro fork on github..."))
-    gh_user_repos = fetch_github_api('https://api.github.com/users/{0}/repos?per_page=100'.format(gh_username))
+    gh_user_repos = fetch_github_api('https://api.github.com/users/{0}/repos'.format(gh_username), use_pagination=True)
     if gh_user_repos is None:
         error("Failed to get a list of repositories for user: '{0}'".format(gh_username))
         warning("Skipping the pull request...")
@@ -457,11 +475,11 @@ Increasing version of package(s) in repository `{0}`:
             _my_run('git fetch')
             track_branches()
             branches = get_branches()
-            new_branch = 'bloom-patch-{0}'
+            new_branch = 'bloom-{repository}-{count}'
             count = 0
-            while new_branch.format(count) in branches:
+            while new_branch.format(repository=repository, count=count) in branches:
                 count += 1
-            new_branch = new_branch.format(count)
+            new_branch = new_branch.format(repository=repository, count=count)
             # Final check
             info(fmt("@{cf}Pull Request Title: @{yf}" + title))
             info(fmt("@{cf}Pull Request Body : \n@{yf}" + body))
@@ -724,8 +742,9 @@ def perform_release(repository, track, distro, new_track, interactive, pretend):
         try:
             pull_request_url = open_pull_request(track, repository, distro)
             if pull_request_url:
-                info(fmt(_success) + "Pull request opened at: '{0}'".format(pull_request_url))
-                webbrowser.open(pull_request_url)
+                info(fmt(_success) + "Pull request opened at: {0}".format(pull_request_url))
+                if 'BLOOM_NO_WEBBROWSER' in os.environ and platform.system() not in ['Darwin']:
+                    webbrowser.open(pull_request_url)
             else:
                 info("The release of your packages was successful, but the pull request failed.")
                 info("Please manually open a pull request by editing the file here: '{0}'"
@@ -750,6 +769,8 @@ def get_argument_parser():
         help="if used, a new track will be created before running bloom")
     add('--pretend', '-p', default=False, action='store_true',
         help="Pretends to push and release")
+    add('--no-web', default=False, action='store_true',
+        help="prevents a web browser from being opened at the end")
     return parser
 
 _quiet = False
@@ -765,6 +786,9 @@ def main(sysargs=None):
         list_tracks(args.repository, args.ros_distro)
         return
 
+    if args.no_web:
+        os.environ['BLOOM_NO_WEBBROWSER'] = '1'
+
     try:
         os.environ['BLOOM_TRACK'] = args.track
         disable_git_clone(True)
